/*
 * XOSD
 * 
 * Copyright (c) 2000 Andre Renaud (andre@ignavus.net)
 * 
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 675 Mass Ave, Cambridge, MA 02139, USA. 
 */
//#include "intern.h"

#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

#include "xosd.h"
#include "org_beanizer_jxosd_JXosd.h"

xosd *osd;

JNIEXPORT void JNICALL Java_org_beanizer_jxosd_JXosd_initialize (JNIEnv* env, jobject obj, jint lines){	
	osd = xosd_create(lines);
	xosd_set_timeout(osd,2);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_destroy (JNIEnv* env, jobject obj) {
	return xosd_destroy(osd);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_show (JNIEnv* env, jobject obj) {
	return xosd_show(osd);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_hide (JNIEnv* env, jobject obj) {
	return xosd_hide(osd);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_getNumberLines (JNIEnv* env, jobject obj) {
	return xosd_get_number_lines(osd);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_isOnScreen (JNIEnv* env, jobject obj) {
	return xosd_is_onscreen(osd);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_waitUntilNoDisplay (JNIEnv* env, jobject obj) {
	return xosd_wait_until_no_display(osd);
}


JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setPosition (JNIEnv* env, jobject obj, jint pos){
	return xosd_set_pos(osd, pos);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setAlign (JNIEnv* env, jobject obj, jint pos){
	return xosd_set_align(osd, pos);
}


JNIEXPORT void JNICALL Java_org_beanizer_jxosd_JXosd_setTimeout (JNIEnv* env, jobject obj, jint timeout){
	xosd_set_timeout(osd, timeout);
}


JNIEXPORT void JNICALL Java_org_beanizer_jxosd_JXosd_setBarLength (JNIEnv* env, jobject obj, jint length){
	xosd_set_bar_length(osd, length);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setColor (JNIEnv* env, jobject obj, jstring color){
	jboolean iscopy;
	int a;
	const char *colour = (*env)->GetStringUTFChars(env, color, &iscopy);
	a = xosd_set_colour(osd,colour);
	(*env)->ReleaseStringUTFChars(env, color, colour);	
	return a;
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setFont (JNIEnv* env, jobject obj, jstring font){
	jboolean iscopy;
	int a;
	const char *myfont = (*env)->GetStringUTFChars(env, font, &iscopy);
	a = xosd_set_font(osd,myfont);
	(*env)->ReleaseStringUTFChars(env, font, (char *) myfont);	
	return a;
}


JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setOutlineColor (JNIEnv* env, jobject obj, jstring color){
	jboolean iscopy;
	int a;
	const char *colour = (*env)->GetStringUTFChars(env, color, &iscopy);
	a = xosd_set_outline_colour(osd,colour);
	(*env)->ReleaseStringUTFChars(env, color, colour);	
	return a;
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setOutlineOffset (JNIEnv* env, jobject obj, jint offset){
	return xosd_set_outline_offset(osd, offset);
}


JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setShadowColor (JNIEnv* env, jobject obj, jstring color){
	jboolean iscopy;
	int a;
	const char *colour = (*env)->GetStringUTFChars(env, color, &iscopy);
	a = xosd_set_shadow_colour(osd,colour);
	(*env)->ReleaseStringUTFChars(env, color, colour);	
	return a;
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setShadowOffset (JNIEnv* env, jobject obj, jint offset){
	return xosd_set_shadow_offset(osd, offset);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setHorizontalOffset (JNIEnv* env, jobject obj, jint offset){
	return xosd_set_horizontal_offset(osd, offset);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_setVerticalOffset (JNIEnv* env, jobject obj, jint offset){
	return xosd_set_vertical_offset(osd, offset);
}


JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_showText (JNIEnv* env, jobject obj, jint line, jstring text){
	jboolean iscopy;
	int a;
	const char *mytext = (*env)->GetStringUTFChars(env, text, &iscopy);
	a = xosd_display(osd, line, XOSD_string, mytext);
	(*env)->ReleaseStringUTFChars(env, text, mytext);	
	return a;
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_showPercentage (JNIEnv* env, jobject obj, jint line, jint value){
	return xosd_display(osd, line, XOSD_percentage, value);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_showSlider (JNIEnv* env, jobject obj, jint line, jint value){
	return xosd_display(osd, line, XOSD_slider, value);
}

JNIEXPORT jint JNICALL Java_org_beanizer_jxosd_JXosd_scroll (JNIEnv* env, jobject obj, jint lines){
	return xosd_scroll(osd, lines);
}

